cordova.define("cordova-plugin-etas-ifaa.etasIfaa", function(require, exports, module) {
// eslint-disable-next-line
var exec = require('cordova/exec');

/**
 * window.cordova.plugins.etasIfaa
 */
function EtasIfaa() {
  /**
   * @param options {Object}
   *  1. trancId
   *     业务 ID, 请保持唯一，记录在 ifaa log 中，当出问题时候，查问题用。
   *  2. payload
   *     业务的附加信息，记录在ifaa log 中，作为扩展字段不能为null，可为空字符串，当出问题时，查问题用。
   *  3. trancType
   *     本次IFAA操作的业务场景，比如登录："Login"，支付："Pay"
   *     业务的附加信息，记录在 ifaa log 中，当出问题时，查问题用。
   *  4. userId
   *     用户 id, 此值参与 ifaa 业务以及 token 的生成，务必保证其唯一，可以传入用户名的 hash 值来脱敏。
   *  5. reasonTitle
   *     设置使用 SDK 提供的指纹弹框页面，左键
   *     iOS 验证理由说明文字，会显示在对话框中部。
   *  6. fallbackTitle
   *     验证指纹弹框时在错误一次的后显示出的可选项按钮标题，若需要取消该按钮的显示，传入一个空字符串即可。
   *  7. cancelTitle
   *     取消按钮显示文字（iOS）
   *  8. url
   *     设置 IFAA 服务器的 url 地址。(留空)
   *  9. authNumber
   *     设置指纹框认证次数（Android）
   *  10. authType
   *     设置认证类型
   *     Android:
   *       AUTHTYPE_FINGERPRINT(1),
   *       AUTHTYPE_IRIS(2),
   *       AUTHTYPE_FACE(4),
   *       AUTHTYPE_HARDWARE_IC(8),
   *       AUTHTYPE_IN_SCREEN_FINGERPRINT(16);
   *     iOS:
   *       AUTHTYPE_FINGERPRINT = 1,
   *       AUTHTYPE_FACEID = 4,
   *  11. useLocalAuth
   *      是否进行本地指纹验证（该属性只能控制注册流程中是否进行本地指纹验证）
   *
   * @param successCallback
   *  successCallback 参数: 无
   *
   * @param errorCallback
   *  errorCallback 参数:
   *    1. message{String}
   *    2. code{String}
   */
  this.initIfaaBaseInfo = function (options, successCallback, errorCallback) {
    exec(successCallback, errorCallback, 'EtasIfaa', 'initIfaaBaseInfo', [options || {}]);
  };
  /**
   * @param options {Object}
   *  1. authType (Integer)
   *     设置认证类型
   *     Android
   *       1 - AUTHTYPE_FINGERPRINT,
   *       2 - AUTHTYPE_IRIS,
   *       4 - AUTHTYPE_FACE,
   *       8 - AUTHTYPE_HARDWARE_IC,
   *       16 - AUTHTYPE_IN_SCREEN_FINGERPRINT;
   *    iOS
   *       1 - AUTHTYPE_FINGERPRINT,
   *       4 - AUTHTYPE_FACE,
   * @param successCallback
   *  successCallback 参数:
   *    1. result{Boolean}
   *    2. code{String}
   *
   * @param errorCallback
   *  errorCallback 参数:
   *    1. message{String}
   *    2. code{String}
   */
  this.isSupportIfaa = function (options, successCallback, errorCallback) {
    exec(successCallback, errorCallback, 'EtasIfaa', 'isSupportIfaa', [options || {}]);
  };
  /** @param successCallback
   *  successCallback 参数:
   *    1. result{Boolean}
   *    2. code{String}
   *
   * @param errorCallback
   *  errorCallback 参数:
   *    1. message{String}
   *    2. code{String}
   */
  this.hasPermissionForFaceID = function (successCallback, errorCallback) {
    exec(successCallback, errorCallback, 'EtasIfaa', 'hasPermissionForFaceID', [{}]);
  };
  /**
   * @param successCallback
   *  successCallback 参数:
   *    1. message{String}
   *    2. code{String}
   *
   * @param errorCallback
   *  errorCallback 参数:
   *    1. message{String}
   *    2. code{String}
   */
  this.regInit = function (options, successCallback, errorCallback) {
    exec(successCallback, errorCallback, 'EtasIfaa', 'regInit', [options || {}]);
  };
  /**
   * @param options {Object}
   *  1. ifaaMsg
   *
   * @param successCallback
   *  successCallback 参数:
   *    1. message{String}
   *    2. code{String}
   *
   * @param errorCallback
   *  errorCallback 参数:
   *    1. message{String}
   *    2. code{String}
   */
  this.register = function (options, successCallback, errorCallback) {
    exec(successCallback, errorCallback, 'EtasIfaa', 'register', [options || {}]);
  };
  /**
   * @param options {Object}
   *  1. ifaaMsg
   *
   * @param successCallback
   *  successCallback 参数:
   *    1. message{String}
   *    2. code{String}
   *
   * @param errorCallback
   *  errorCallback 参数:
   *    1. message{String}
   *    2. code{String}
   */
  this.regFinish = function (options, successCallback, errorCallback) {
    exec(successCallback, errorCallback, 'EtasIfaa', 'regFinish', [options || {}]);
  };

  /**
   * @param successCallback
   *  successCallback 参数:
   *    1. message{String}
   *    2. code{String}
   *
   * @param errorCallback
   *  errorCallback 参数:
   *    1. message{String}
   *    2. code{String}
   */
  this.authInit = function (options, successCallback, errorCallback) {
    exec(successCallback, errorCallback, 'EtasIfaa', 'authInit', [options || {}]);
  };

  /**
   * @param options {Object}
   *  1. ifaaMsg
   *
   * @param successCallback
   *  successCallback 参数:
   *    1. message{String}
   *    2. code{String}
   *
   * @param errorCallback
   *  errorCallback 参数:
   *    1. message{String}
   *    2. code{String}
   */
  this.auth = function (options, successCallback, errorCallback) {
    exec(successCallback, errorCallback, 'EtasIfaa', 'auth', [options || {}]);
  };
  /**
   * @param options {Object}
   *  1. ifaaMsg
   *
   * @param successCallback
   *  successCallback 参数:
   *    1. message{String}
   *    2. code{String}
   *
   * @param errorCallback
   *  errorCallback 参数:
   *    1. message{String}
   *    2. code{String}
   */
  this.authFinish = function (options, successCallback, errorCallback) {
    exec(successCallback, errorCallback, 'EtasIfaa', 'authFinish', [options || {}]);
  };
  /**
   * @param successCallback
   *  successCallback 参数:
   *    1. message{String}
   *    2. code{String}
   *
   * @param errorCallback
   *  errorCallback 参数:
   *    1. message{String}
   *    2. code{String}
   */
  this.checkStatusInit = function (options, successCallback, errorCallback) {
    exec(successCallback, errorCallback, 'EtasIfaa', 'checkStatusInit', [options || {}]);
  };
  /**
   * @param options {Object}
   *  1. ifaaMsg
   *
   * @param successCallback
   *  successCallback 参数:
   *    1. message{String}
   *    2. code{String}
   *
   * @param errorCallback
   *  errorCallback 参数:
   *    1. message{String}
   *    2. code{String}
   */
  this.parseResult = function (options, successCallback, errorCallback) {
    exec(successCallback, errorCallback, 'EtasIfaa', 'parseResult', [options || {}]);
  };
  /**
   * @param options {Object}
   *  1. token
   *
   * @param successCallback
   *  successCallback 参数:
   *    1. message{String}
   *    2. code{String}
   *
   * @param errorCallback
   *  errorCallback 参数:
   *    1. message{String}
   *    2. code{String}
   */
  this.checkLocalStatus = function (options, successCallback, errorCallback) {
    exec(successCallback, errorCallback, 'EtasIfaa', 'checkLocalStatus', [options || {}]);
  };
  /**
   * @param options {Object}
   *  1. ifaaMsg
   *
   * @param successCallback
   *  successCallback 参数:
   *    1. message{String}
   *    2. code{String}
   *
   * @param errorCallback
   *  errorCallback 参数:
   *    1. message{String}
   *    2. code{String}
   */
  this.templateUpdaInit = function (options, successCallback, errorCallback) {
    exec(successCallback, errorCallback, 'EtasIfaa', 'templateUpdaInit', [options || {}]);
  };
  /**
   * @param options {Object}
   *  1. ifaaMsg
   *
   * @param successCallback
   *  successCallback 参数:
   *    1. message{String}
   *    2. code{String}
   *
   * @param errorCallback
   *  errorCallback 参数:
   *    1. message{String}
   *    2. code{String}
   */
  this.templateUpdaFinish = function (options, successCallback, errorCallback) {
    exec(successCallback, errorCallback, 'EtasIfaa', 'templateUpdaFinish', [options || {}]);
  };
  /**
   * @param successCallback
   *  successCallback 参数:
   *    1. message{String}
   *    2. code{String}
   *
   * @param errorCallback
   *  errorCallback 参数:
   *    1. message{String}
   *    2. code{String}
   */
  this.deregInit = function (options, successCallback, errorCallback) {
    exec(successCallback, errorCallback, 'EtasIfaa', 'deregInit', [options || {}]);
  };
  /**
   * @param options {Object}
   *  1. ifaaMsg
   *
   * @param successCallback
   *  successCallback 参数:
   *    1. message{String}
   *    2. code{String}
   *
   * @param errorCallback
   *  errorCallback 参数:
   *    1. message{String}
   *    2. code{String}
   */
  this.dereg = function (options, successCallback, errorCallback) {
    exec(successCallback, errorCallback, 'EtasIfaa', 'dereg', [options || {}]);
  };
  /**
   * @param successCallback
   *  successCallback 参数:
   *    1. message{String}
   *    2. code{String}
   *
   * @param errorCallback
   *  errorCallback 参数:
   *    1. message{String}
   *    2. code{String}
   */
  this.sendAuthStatusCodeComplete = function (successCallback, errorCallback) {
    exec(successCallback, errorCallback, 'EtasIfaa', 'sendAuthStatusCodeComplete', [{}]);
  };
}

module.exports = new EtasIfaa();

});
